@@ -460,92 +460,6 @@ def recall(
                             num_classes=num_classes, class_reduction=class_reduction)[1]
 
 
-def fbeta_score(
-        pred: torch.Tensor,
-        target: torch.Tensor,
-        beta: float,
-        num_classes: Optional[int] = None,
-        class_reduction: str = 'micro',
-) -> torch.Tensor:
-    """
-    Computes the F-beta score which is a weighted harmonic mean of precision and recall.
-    It ranges between 1 and 0, where 1 is perfect and the worst value is 0.
-
-    Args:
-        pred: estimated probabilities
-        target: ground-truth labels
-        beta: weights recall when combining the score.
-            beta < 1: more weight to precision.
-            beta > 1 more weight to recall
-            beta = 0: only precision
-            beta -> inf: only recall
-        num_classes: number of classes
-        class_reduction: method to reduce metric score over labels
-
-            - ``'micro'``: calculate metrics globally (default)
-            - ``'macro'``: calculate metrics for each label, and find their unweighted mean.
-            - ``'weighted'``: calculate metrics for each label, and find their weighted mean.
-            - ``'none'``: returns calculated metric per class
-
-    Return:
-        Tensor with the value of F-score. It is a value between 0-1.
-
-    Example:
-
-        >>> x = torch.tensor([0, 1, 2, 3])
-        >>> y = torch.tensor([0, 1, 2, 2])
-        >>> fbeta_score(x, y, 0.2)
-        tensor(0.7500)
-    """
-    # We need to differentiate at which point to do class reduction
-    intermidiate_reduction = 'none' if class_reduction != "micro" else 'micro'
-
-    prec, rec, sups = precision_recall(pred=pred, target=target,
-                                       num_classes=num_classes,
-                                       class_reduction=intermidiate_reduction,
-                                       return_support=True)
-    num = (1 + beta ** 2) * prec * rec
-    denom = ((beta ** 2) * prec + rec)
-    if intermidiate_reduction == 'micro':
-        return torch.sum(num) / torch.sum(denom)
-    return class_reduce(num, denom, sups, class_reduction=class_reduction)
-
-
-def f1_score(
-        pred: torch.Tensor,
-        target: torch.Tensor,
-        num_classes: Optional[int] = None,
-        class_reduction: str = 'micro',
-) -> torch.Tensor:
-    """
-    Computes the F1-score (a.k.a F-measure), which is the harmonic mean of the precision and recall.
-    It ranges between 1 and 0, where 1 is perfect and the worst value is 0.
-
-    Args:
-        pred: estimated probabilities
-        target: ground-truth labels
-        num_classes: number of classes
-        class_reduction: method to reduce metric score over labels
-
-            - ``'micro'``: calculate metrics globally (default)
-            - ``'macro'``: calculate metrics for each label, and find their unweighted mean.
-            - ``'weighted'``: calculate metrics for each label, and find their weighted mean.
-            - ``'none'``: returns calculated metric per class
-
-    Return:
-         Tensor containing F1-score
-
-    Example:
-
-        >>> x = torch.tensor([0, 1, 2, 3])
-        >>> y = torch.tensor([0, 1, 2, 2])
-        >>> f1_score(x, y)
-        tensor(0.7500)
-    """
-    return fbeta_score(pred=pred, target=target, beta=1.,
-                       num_classes=num_classes, class_reduction=class_reduction)
-
-
 def _binary_clf_curve(
         pred: torch.Tensor,
         target: torch.Tensor,
